//--------------------------------------------------------------
// File     : stm32_ub_din_dma.h
//--------------------------------------------------------------

//--------------------------------------------------------------
#ifndef __STM32F4_UB_DIN_DMA_H
#define __STM32F4_UB_DIN_DMA_H


//--------------------------------------------------------------
// Includes
//--------------------------------------------------------------
#include "stm32f4xx.h"
#include "stm32f4xx_gpio.h"
#include "stm32f4xx_rcc.h"
#include "stm32f4xx_tim.h"
#include "stm32f4xx_dma.h"
#include "misc.h"




//--------------------------------------------------------------
// Port Einstellungen
// Eine der drei Mglichkeiten aktivieren
// die beiden anderen auskommentieren
//--------------------------------------------------------------

//#define DIN_DMA_USE_BIT0TO7   1  // 8 Kanle (an Port Bit0 bis Bit7)
#define DIN_DMA_USE_BIT8TO15  2  // 8 Kanle (an Port Bit8 bis Bit15)
//#define DIN_DMA_USE_BIT0TO15  3  // 16 Kanle (an Port Bit0 bis Bit15)


//--------------------------------------------------------------
// Anzahl der Werte
//--------------------------------------------------------------
#define  DIN_DMA_LENGTH  100



#ifdef DIN_DMA_USE_BIT0TO15
  uint16_t DIN_DMA_PUFFER[DIN_DMA_LENGTH];  // 16bit
#else
  uint8_t DIN_DMA_PUFFER[DIN_DMA_LENGTH];   // 8bit
#endif


//--------------------------------------------------------------
// Adressen vom benutzten Port (Register IDR)
// um per DMA darauf zuzugreifen
// (siehe Seite 53+204 vom Referenz Manual)
// im Beispiel wird Port-E benutzt
//--------------------------------------------------------------
#define DIN_DMA_GPIOE_BASE_ADR     ((uint32_t)0x40021000) // ADR von Port-E
#define DIN_DMA_GPIO_IDR_OFFSET    ((uint32_t)0x00000010) // ADR von Register IDR
#define DIN_DMA_GPIO_BYTE_OFFSET   ((uint32_t)0x00000001) // falls Bit8 bis Bit15


#ifdef DIN_DMA_USE_BIT8TO15
  #define DIN_DMA_GPIOE_IDR_ADDRESS   (DIN_DMA_GPIOE_BASE_ADR | DIN_DMA_GPIO_IDR_OFFSET | DIN_DMA_GPIO_BYTE_OFFSET)
#else
  #define DIN_DMA_GPIOE_IDR_ADDRESS   (DIN_DMA_GPIOE_BASE_ADR | DIN_DMA_GPIO_IDR_OFFSET)
#endif



//--------------------------------------------------------------
// Timer-1
// Funktion  = GPIOs einlesen (Takt fr den DMA Transver)
//
// Grundfreq = 2*APB2 (APB2=84MHz) => TIM_CLK=168MHz
// FRQ       = CLK / (Prescale+1) / (Periode+1)
// Frq       = 168MHz/100/168 = 10kHz
//--------------------------------------------------------------
#define DIN_DMA_TIM1_PERIODE      167
#define DIN_DMA_TIM1_PRESCALE      99



//--------------------------------------------------------------
typedef enum {
  DIN_DMA_READY =0,  // ready zum auslesen
  DIN_DMA_RUNNING    // busy
}DIN_DMA_STATUS_t;



//--------------------------------------------------------------
// Globale Funktionen
//--------------------------------------------------------------
void UB_DIN_DMA_Init(void);
void UB_DIN_DMA_Start(void);
DIN_DMA_STATUS_t UB_DIN_DMA_Check(void);
uint8_t UB_DIN_DMA_ReadKanal(uint8_t kanal, uint32_t position);
uint16_t UB_DIN_DMA_ReadAll(uint32_t position);



//--------------------------------------------------------------
#endif // __STM32F4_UB_DIN_DMA_H
